@@ -4,7 +4,7 @@ use Moose;
 use Scalar::Util 'blessed';
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
-our $VERSION = '0.007';
+our $VERSION = '0.008';
 
 sub mvp_multivalue_args { qw/mma_WriteMakefile_arg mma_header mma_footer mma_test_file mma_exe_file/ }
 
@@ -194,4 +194,5 @@ the terms of the Artistic License version 2.0.
 
 =head1 SEE ALSO
 
-L<Dist::Zilla>, L<Dist::Zilla::Plugin::MakeMaker::Awesome>, L<cpanfile>
+L<Dist::Zilla>, L<Dist::Zilla::Plugin::MakeMaker::Awesome>, L<cpanfile>,
+L<Dist::Zilla::MintingProfile::Author::DBOOK>
